#
# spec file for package kgeotag
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kgeotag
Version:        1.2.0
Release:        bp154.1.24
Summary:        A photo geotagging utility
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://kgeotag.kde.org/
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KExiv2)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Marble)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets) >= 5.14.0
Recommends:     marble

%description
KGeoTag is a standalone geotagging program.
Images can be associated with geographic coordinates
by different means: On the one hand, a matching with
GPX encoded geodata can be done, on the other hand,
the coordinates can be set manually, either via drag
and drop onto a map, via bookmarks or by manually
supplying them. The coordinates can be stored in the
images' Exif header and/or in XMP sidecar files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%if %{with lang}
%find_lang %{name}
%endif

%files
%license LICENSES/*
%doc ChangeLog.rst README.md
%{_kf5_applicationsdir}/org.kde.kgeotag.desktop
%{_kf5_appstreamdir}/org.kde.kgeotag.appdata.xml
%{_kf5_bindir}/kgeotag
%{_kf5_iconsdir}/hicolor/*/apps/kgeotag.png
%{_kf5_kxmlguidir}/kgeotag/
%{_kf5_sharedir}/kgeotag/

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Sun Nov 14 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.2.0
  * Enhancement: KGeoTag now checks if the timezone data files
    could actually be loaded and displays a warning about timezone
    detection not working if not.
  * Bugfix: Made selecting all entries of an image list work again
    via the standard shortcut CTRL+A. This one was assigned to
    "Assign images to GPS data", which can now be  accessed via
    CTRL+M.  (kde#445023)
  * Bugfix: QMimeDatabase::mimeTypeForFile now returns
    application/xml+gpx as a GPX file's MIME type instead of
    application/x-gpx+xml - at least here on my stable Gentoo
    machine. This made KGeoTag refuse to load any GPX file. Now,
    both MIME types are accepted.
  * Change: Suppressed a warning by bumping cmake_minimum_required
    to 3.16.0.
* Mon Oct 25 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.1.0
  * Bugfix: When walking along a track, the date and time were
    displayed to be in the set timezone, but not actually converted
    to it. Now, the timestamps are translated correctly.
  * Enhancement: Added an "Assign images to GPS data" main menu
    entry. This one triggers an automatic image assignment af all
    loaded images, like "(Re)Assign all images" from the "Automatic
    assignment" dock. The search type to perform can be defined in
    the settings.
  * Bugfix: Enabled exact matching also if a used GPX track and/or
    the image metadata contain milliseconds. If so, the
    `QHash<QDateTime, ...>::contains()` call used to search for
    exact matches won't yield a result, even if there's a
    seconds-exact match (if not also the milliseconds matched, and
    this is quite unlikely).
- Drop 0001-Don-t-look-for-a-specific-Marble-version.patch, merged
  upstream
- Change URL to new project homepage
* Wed Aug 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix the marble detection:
  * 0001-Don-t-look-for-a-specific-Marble-version.patch
* Sun Jun 27 2021 Wolfgang Bauer <wbauer@tmo.at>
- Initial package
